@@ -1,15 +1,14 @@
-from datetime import timedelta
 from abc import ABC, abstractmethod
-from typing import Generic, Optional, TypeVar, List, Any, Union, Callable
+from datetime import timedelta
+from typing import Any, Callable, Generic, List, Optional, Union
 from weakref import WeakMethod
 
-from highwire.events import Event, project
 from highwire import events, exceptions
+from highwire.events import Event, project
+from highwire.variables import R, S, T
 
-R = TypeVar("R")
-S = TypeVar("S")
-T = TypeVar("T")
 
+Tick = Event[object]
 
 Subscription = Any
 
@@ -40,6 +39,12 @@ class Signal(Generic[T], ABC):
         return Difference(self, other)
 
 
+class Sampler(Signal[T]):
+    @abstractmethod
+    def sample(self, tick: Tick) -> None:
+        pass
+
+
 class BinaryOperation(Signal[S]):
     _current: Optional[S]
 
@@ -194,7 +199,7 @@ class Sum(Signal[Number]):
     def get(self) -> Optional[Number]:
         return self._current
 
-    def _update(self, new: Event[Number]) -> Number:
+    def _update(self, new: Event[Number]) -> None:
         self._current += new.value
         self._events.append(new)
         before = new.time - self._keep
@@ -202,4 +207,37 @@ class Sum(Signal[Number]):
         for event in dropped:
             self._current -= event.value
         self._notify(project(new, lambda _: self._current))
+
+
+class Crossing(Signal[Number]):
+    _previous: Optional[Number]
+    _current: Optional[Number]
+
+    def __init__(self, signal: Signal[Number], threshold: Number):
+        super().__init__()
+        self._threshold = threshold
+        self._previous = None
+        self._current = None
+        self._signal = signal
+        signal.subscribe(self._update)
+
+    def get(self) -> Optional[Number]:
         return self._current
+
+    def _update(self, new: Event[Number]) -> None:
+        if new.value == self._threshold or new.value is None:
+            self._current = 0
+        else:
+            if self._previous is None:
+                self._current = 0
+            elif self._previous < self._threshold and self._threshold < new.value:
+                self._current = 1
+            elif new.value < self._threshold and self._threshold < self._previous:
+                self._current = -1
+            else:
+                self._current = 0
+            self._previous = new.value
+
+
+def Crossover(x: Signal[Number], y: Signal[Number]) -> Signal[Number]:
+    return Crossing(x - y, 0)
